/*
 *  OpenGL 3.x Demonstration
 *  
 *  for the "Computergraphics 2" lab
 *
 *  Institute of Computer Graphics and Algorithms
 *  Vienna University of Technology
 *  Vienna, Austria
 *
 *  March 2010
 *
 *  ginquo
 */

// Note: If running OpenGL 2.1, you have to do the following to get it to run:
//       1. delete the two marked lines
//       2. rename 'in' to 'attribute'
//       3. rename 'out' to 'varying'

#version 130              // delete this line if using GLSL 1.2
precision mediump float;  // delete this line if using GLSL 1.2

// uniform shader-parameters
uniform vec4 light_position;
uniform vec4 light_color;
uniform vec4 ambient_color;
uniform vec4 spec_color;
uniform sampler2D ctexture;
uniform vec3 camPos;
//materials
uniform vec4 ka;
uniform vec4 kd;
uniform vec4 ks;

// fragment-shader input variables
in vec4 frag_color;
in vec3 world_normal;
in vec4 world_position;
in vec2 fragTexCoord;

// fragment-shader output variable (-> stored in the frame-buffer, i.e. "the pixel you see")
out vec4 fragColor;

void main()
{
	// renormalize and homogenize input variables
	vec3 normal = normalize(world_normal);
    vec3 position = world_position.xyz / world_position.w;
    
    // calculate the light-direction
    vec3 light_dir = normalize(light_position.xyz - position);
   
    
    // calculate lighting
    vec4 texel = texture(ctexture, fragTexCoord);
    vec4 ambient = ka * ambient_color * texel;
    vec4 diffuse = kd * texel * light_color * max(0.0, dot(normal, light_dir));
    
//     //calculate specular
//     vec3 view = normalize(camPos - position);
//     vec3 H = normalize(view + light_dir);
//     vec4 specular = spec_color * pow(max(0.0, dot(normal, H)), 5.0);
    
    // write color to output
    fragColor = ambient + diffuse;
    //fragColor = vec4(1, 1, 1, 1);
}
